arrc.models.embeddings.bayesian\_cnn\_lstm
==========================================

.. automodule:: arrc.models.embeddings.bayesian_cnn_lstm

   
   .. rubric:: Functions

   .. autosummary::
   
      build_bayesian_cnn_lstm_model
   